@@ -1,6 +1,7 @@
 "Common functions that may be used everywhere"
 
-from __future__ import print_function, unicode_literals
+from __future__ import (absolute_import, division,
+                        print_function, unicode_literals)
 
 import os
 import sys
